FAME3R
------

.. list-table::
    :widths: 30 70

    * - **Documentation**
      - |docs|
    * - **Code Quality**
      - |build| |check| |test|
    * - **Sources**
      - |pypi-version| |conda-version|
    * - **License**
      - |license|

Description
***********

FAME3R is a random forest model predicting the phase 1 and phase 2 sites of metabolism (*SOMs*) in small organic molecules. SOMs are atoms where a metabolic reaction gets initiated and, thus, are a good starting point for determining the metabolic fate of xenobiotic compounds.

Documentation
*************

The documentation, including installation instructions, tutorials for using the software, and full Python API documentation can be found online on `GitHub Pages <https://molinfo-vienna.github.io/FAME3R/main/html/>`_.

Citation
********

Please refer to the `Citation <https://molinfo-vienna.github.io/FAME3R/main/html/source/citation.html>`_ section in our documentation.

License
*******

Unless otherwise noted, all files in this directory and all subdirectories are distributed under the MIT License.

.. |pypi-version| image:: https://img.shields.io/pypi/v/fame3r.svg
   :target: https://pypi.python.org/pypi/fame3r
   :alt: PyPi Version

.. |conda-version| image:: https://img.shields.io/conda/vn/conda-forge/fame3r.svg
    :target: https://anaconda.org/conda-forge/fame3r
    :alt: conda-forge version

.. |build| image:: https://img.shields.io/github/actions/workflow/status/molinfo-vienna/FAME3R/build.yml?label=build
    :target: https://github.com/molinfo-vienna/FAME3R/actions/workflows/build.yml
    :alt: Build status

.. |check| image:: https://img.shields.io/github/actions/workflow/status/molinfo-vienna/FAME3R/check.yml?label=check
    :target: https://github.com/molinfo-vienna/FAME3R/actions/workflows/check.yml
    :alt: Code quality checks status

.. |test| image:: https://img.shields.io/github/actions/workflow/status/molinfo-vienna/FAME3R/test.yml?label=test
    :target: https://github.com/molinfo-vienna/FAME3R/actions/workflows/test.yml
    :alt: Tests status

.. |docs| image:: https://img.shields.io/github/actions/workflow/status/molinfo-vienna/FAME3R/docs.yml?label=main&color=turquoise
    :target: https://molinfo-vienna.github.io/FAME3R/main/html/
    :alt: Documentation status

.. |license| image:: https://img.shields.io/github/license/molinfo-vienna/FAME3R
    :target: https://github.com/molinfo-vienna/FAME3R/blob/main/LICENSE
    :alt: License
